@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -17,14 +16,16 @@
 #include "H5Exception.h"
 #include "H5IdComponent.h"
 #include "H5PropList.h"
-#include "H5StrcreatProp.h"
+#include "H5OcreatProp.h"
+#include "H5DcreatProp.h"
+#include "H5DxferProp.h"
 #include "H5LcreatProp.h"
 #include "H5LaccProp.h"
+#include "H5DaccProp.h"
 #include "H5Location.h"
 #include "H5Object.h"
 #include "H5Alltypes.h"
 #include "H5AbstractDs.h"
-#include "H5DxferProp.h"
 #include "H5DataSpace.h"
 #include "H5DataSet.h"
 
@@ -33,7 +34,6 @@ namespace H5 {
 //--------------------------------------------------------------------------
 // Function:    CompType default constructor
 ///\brief       Default constructor: Creates a stub compound datatype
-// 2000
 //--------------------------------------------------------------------------
 CompType::CompType() : DataType()
 {
@@ -41,9 +41,8 @@ CompType::CompType() : DataType()
 
 //--------------------------------------------------------------------------
 // Function:    CompType copy constructor
-///\brief       Copy constructor: makes copy of the original CompType object
+///\brief       Copy constructor: same HDF5 object as \a original
 ///\param       original - IN: Original CompType instance
-// 2000
 //--------------------------------------------------------------------------
 CompType::CompType(const CompType &original) : DataType(original)
 {
@@ -53,7 +52,6 @@ CompType::CompType(const CompType &original) : DataType(original)
 // Function:    CompType overloaded constructor
 ///\brief       Creates a CompType object using the id of an existing datatype.
 ///\param       existing_id - IN: Id of an existing compound datatype
-// 2000
 //--------------------------------------------------------------------------
 CompType::CompType(const hid_t existing_id) : DataType(existing_id)
 {
@@ -67,7 +65,6 @@ CompType::CompType(const hid_t existing_id) : DataType(existing_id)
 // Description
 //              The DataType constructor calls the C API H5Tcreate to create
 //              the compound datatype.
-// 2000
 //--------------------------------------------------------------------------
 CompType::CompType(size_t size) : DataType(H5T_COMPOUND, size)
 {
@@ -79,7 +76,6 @@ CompType::CompType(size_t size) : DataType(H5T_COMPOUND, size)
 ///\param       dataset - IN: Dataset that this enum datatype associates with
 ///\return      CompType instance
 ///\exception   H5::DataTypeIException
-// 2000
 //--------------------------------------------------------------------------
 CompType::CompType(const DataSet &dataset) : DataType()
 {
@@ -96,46 +92,44 @@ CompType::CompType(const DataSet &dataset) : DataType()
 // Function:    CompType overloaded constructor
 ///\brief       Creates an CompType instance by opening an HDF5 compound
 ///             given its name, provided as a C character string.
-///\param       loc       - IN: Location of the type
-///\param       type_name - IN: Compound type name
+///\param       loc        - IN: Location of the type
+///\param       dtype_name - IN: Compound type name
 ///\exception   H5::DataTypeIException
-// Sept 2017
 // Description
-//              In 1.8.20, this constructor was introduced and may replace the
+//              In 1.10.1, this constructor was introduced and may replace the
 //              existing function CommonFG::openCompType(const char*) to
 //              improve usability.
-//              -BMR, Sept 2017
+//              -BMR, Dec 2016
 //--------------------------------------------------------------------------
-CompType::CompType(const H5Location &loc, const char *type_name) : DataType()
+CompType::CompType(const H5Location &loc, const char *dtype_name) : DataType()
 {
-    id = p_opentype(loc, type_name);
+    id = p_opentype(loc, dtype_name);
 }
 
 //--------------------------------------------------------------------------
 // Function:    CompType overloaded constructor
 ///\brief       Creates an CompType instance by opening an HDF5 compound
 ///             datatype given its name, provided as an \c H5std_string.
-///\param       loc       - IN: Location of the type
-///\param       type_name - IN: Compound type name
+///\param       loc        - IN: Location of the type
+///\param       dtype_name - IN: Compound type name
 ///\exception   H5::DataTypeIException
-// Sept 2017
 // Description
-//              In 1.8.20, this constructor was introduced and may replace the
-//              existing function CommonFG::openCompType(const H5std_string&) to
-//              improve usability.
-//              -BMR, Sept 2017
+//              In 1.10.1, this constructor was introduced and may replace the
+//              existing function CommonFG::openCompType(const H5Location&)
+//              to improve usability.
+//              -BMR, Dec 2016
 //--------------------------------------------------------------------------
-CompType::CompType(const H5Location &loc, const H5std_string &type_name) : DataType()
+CompType::CompType(const H5Location &loc, const H5std_string &dtype_name) : DataType()
 {
-    id = p_opentype(loc, type_name.c_str());
+    id = p_opentype(loc, dtype_name.c_str());
 }
 
 //--------------------------------------------------------------------------
 // Function:    CompType::decode
 ///\brief       Returns a CompType object via DataType* by decoding the
 ///             binary object description of this datatype.
+///
 ///\exception   H5::DataTypeIException
-// Sept 2017
 //--------------------------------------------------------------------------
 DataType *
 CompType::decode() const
@@ -157,7 +151,6 @@ CompType::decode() const
 ///\brief       Returns the number of members in this compound datatype.
 ///\return      Number of members
 ///\exception   H5::DataTypeIException
-// 2000
 //--------------------------------------------------------------------------
 int
 CompType::getNmembers() const
@@ -176,7 +169,6 @@ CompType::getNmembers() const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      Name of member
 ///\exception   H5::DataTypeIException
-// 2000
 //--------------------------------------------------------------------------
 H5std_string
 CompType::getMemberName(unsigned member_num) const
@@ -195,14 +187,13 @@ CompType::getMemberName(unsigned member_num) const
 //--------------------------------------------------------------------------
 // Function:    CompType::getMemberIndex
 ///\brief       Returns the index of a member in this compound datatype.
-///\param       name - IN: Name of the member - \c char*
+///\param       name - IN: Name of the member
 ///\return      Index of member
 ///\exception   H5::DataTypeIException
 ///\par Description
 ///             Members are stored in no particular order with numbers 0
 ///             through N-1, where N is the value returned by the member
 ///             function \c CompType::getNmembers.
-// May 2002
 //--------------------------------------------------------------------------
 int
 CompType::getMemberIndex(const char *name) const
@@ -213,21 +204,6 @@ CompType::getMemberIndex(const char *name) const
     }
     return (member_index);
 }
-
-//--------------------------------------------------------------------------
-// Function:    CompType::getMemberIndex
-///\brief       This is an overloaded member function, provided for convenience.
-///             It differs from the above function in that it takes an
-///             \c H5std_string for \a name.
-///\param       name - IN: Name of the member - \c H5std_string
-///\return      Index of member
-///\exception   H5::DataTypeIException
-///\par Description
-///             Members are stored in no particular order with numbers 0
-///             through N-1, where N is the value returned by the member
-///             function \c CompType::getNmembers.
-// Apr 2018
-//--------------------------------------------------------------------------
 int
 CompType::getMemberIndex(const H5std_string &name) const
 {
@@ -240,14 +216,13 @@ CompType::getMemberIndex(const H5std_string &name) const
 ///             respect to the beginning of the compound data type datum.
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      Byte offset
-// 2000
 // Description
 ///             Members are stored in no particular order with numbers 0
 ///             through N-1, where N is the value returned by the member
 ///             function \c CompType::getNmembers.
 //
 //              Note that byte offset being returned as 0 doesn't indicate
-//              a failure.
+//              a failure. (According to Quincey)
 //--------------------------------------------------------------------------
 size_t
 CompType::getMemberOffset(unsigned member_num) const
@@ -262,7 +237,6 @@ CompType::getMemberOffset(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      Type class of the member
 ///\exception   H5::DataTypeIException
-// 2000
 // Modification
 //              Modified to use H5Tget_member_class instead. - Jul, 2005
 //--------------------------------------------------------------------------
@@ -301,7 +275,6 @@ CompType::p_get_member_type(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      DataType instance
 ///\exception   H5::DataTypeIException
-// 2000
 //--------------------------------------------------------------------------
 DataType
 CompType::getMemberDataType(unsigned member_num) const
@@ -323,7 +296,6 @@ CompType::getMemberDataType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      ArrayType instance
 ///\exception   H5::DataTypeIException
-// Jul 2005
 //--------------------------------------------------------------------------
 ArrayType
 CompType::getMemberArrayType(unsigned member_num) const
@@ -345,7 +317,6 @@ CompType::getMemberArrayType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      CompType instance
 ///\exception   H5::DataTypeIException
-// 2000
 //--------------------------------------------------------------------------
 CompType
 CompType::getMemberCompType(unsigned member_num) const
@@ -367,7 +338,6 @@ CompType::getMemberCompType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      EnumType instance
 ///\exception   H5::DataTypeIException
-// 2000
 //--------------------------------------------------------------------------
 EnumType
 CompType::getMemberEnumType(unsigned member_num) const
@@ -389,7 +359,6 @@ CompType::getMemberEnumType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      IntType instance
 ///\exception   H5::DataTypeIException
-// 2000
 //--------------------------------------------------------------------------
 IntType
 CompType::getMemberIntType(unsigned member_num) const
@@ -411,7 +380,6 @@ CompType::getMemberIntType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      FloatType instance
 ///\exception   H5::DataTypeIException
-// 2000
 //--------------------------------------------------------------------------
 FloatType
 CompType::getMemberFloatType(unsigned member_num) const
@@ -433,7 +401,6 @@ CompType::getMemberFloatType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      StrType instance
 ///\exception   H5::DataTypeIException
-// 2000
 //--------------------------------------------------------------------------
 StrType
 CompType::getMemberStrType(unsigned member_num) const
@@ -455,7 +422,6 @@ CompType::getMemberStrType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      VarLenType instance
 ///\exception   H5::DataTypeIException
-// Jul 2005
 //--------------------------------------------------------------------------
 VarLenType
 CompType::getMemberVarLenType(unsigned member_num) const
@@ -471,7 +437,7 @@ CompType::getMemberVarLenType(unsigned member_num) const
 }
 
 /* old style of getMemberType - using overloads; new style above
-    returns the appropriate datatypes but has different named functions.
+   returns the appropriate datatypes but has different named functions.
    In the old style, a datatype must be passed into the function.
    May, 2004: These should be reconsidered to provide more convenience.
 // Returns the datatype of the specified member in this compound datatype.
@@ -510,7 +476,6 @@ void CompType::getMemberType(unsigned member_num, StrType& strtype) const
 ///\param       offset - IN: Offset in memory structure of the field to insert
 ///\param       new_member - IN: New member to be inserted
 ///\exception   H5::DataTypeIException
-// 2000
 //--------------------------------------------------------------------------
 void
 CompType::insertMember(const H5std_string &name, size_t offset, const DataType &new_member) const
@@ -533,7 +498,6 @@ CompType::insertMember(const H5std_string &name, size_t offset, const DataType &
 ///\brief       Recursively removes padding from within a compound datatype.
 ///
 ///\exception   H5::DataTypeIException
-// 2000
 //--------------------------------------------------------------------------
 void
 CompType::pack() const
@@ -552,7 +516,6 @@ CompType::pack() const
 ///\exception   H5::DataTypeIException
 // Note
 //      H5Tset_size works on atom datatypes and compound datatypes only
-// March 2014
 //--------------------------------------------------------------------------
 void
 CompType::setSize(size_t size) const
@@ -567,7 +530,6 @@ CompType::setSize(size_t size) const
 //--------------------------------------------------------------------------
 // Function:    CompType destructor
 ///\brief       Properly terminates access to this compound datatype.
-// 2000
 //--------------------------------------------------------------------------
 CompType::~CompType()
 {
