@@ -404,9 +404,6 @@ const H5Z_class2_t H5Z_BOGUS[1] = {{
  * Return       Success: Data chunk size
  *
  *              Failure: 0
- *
- * Programmer   Robb Matzke
- *              Tuesday, April 21, 1998
  *-------------------------------------------------------------------------
  */
 static size_t
@@ -729,8 +726,8 @@ test_nbit_compression(H5File &file)
 
     SUBTEST("N-bit compression (setup)");
 
-    HDmemset(orig_data, 0, DIM1 * DIM2 * sizeof(s1_t));
-    HDmemset(new_data, 0, DIM1 * DIM2 * sizeof(s1_t));
+    memset(orig_data, 0, DIM1 * DIM2 * sizeof(s1_t));
+    memset(new_data, 0, DIM1 * DIM2 * sizeof(s1_t));
 
     try {
         // Define datatypes of members of compound datatype
@@ -1096,7 +1093,7 @@ test_getnativeinfo(H5File &file)
 
         // Get dataset header info
         H5O_native_info_t ninfo;
-        HDmemset(&ninfo, 0, sizeof(ninfo));
+        memset(&ninfo, 0, sizeof(ninfo));
         dataset.getNativeObjinfo(ninfo, H5O_NATIVE_INFO_HDR);
         verify_val(static_cast<long>(ninfo.hdr.nchunks), 1, "DataSet::getNativeObjinfo", __LINE__, __FILE__);
         dataset.close();
@@ -1104,7 +1101,7 @@ test_getnativeinfo(H5File &file)
         // Open the dataset we created above and then close it.  This is one
         // way to open an existing dataset for accessing.
         dataset = file.openDataSet(DSET_DEFAULT_NAME);
-        HDmemset(&ninfo, 0, sizeof(ninfo));
+        memset(&ninfo, 0, sizeof(ninfo));
         dataset.getNativeObjinfo(ninfo, H5O_NATIVE_INFO_ALL);
         verify_val(static_cast<long>(ninfo.hdr.nchunks), 1, "DataSet::getNativeObjinfo", __LINE__, __FILE__);
         dataset.close();
@@ -1366,6 +1363,83 @@ test_operator(H5File &file)
     }
 } // test_operator
 
+/*-------------------------------------------------------------------------
+ * Function:    test_read_string
+ *
+ * Purpose      Tests DataSet::read(H5std_string ...)
+ *
+ * Return       Success: 0
+ *
+ *              Failure: -1
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+test_read_string(H5File &file)
+{
+    SUBTEST("DataSet::read(H5std_string)");
+    try {
+        const H5std_string  DATASET_NAME("test_read_string");
+        const unsigned long NX           = 8;
+        const char          DATA[NX]     = {'a', 0, 0, 0, 0, 0, 0, 'Z'};
+        const H5std_string  EXPECTED_STR = H5std_string(DATA, NX);
+        H5std_string        str;
+
+        /*
+         * Write characters with internal null bytes
+         */
+
+        PredType  datatype(PredType::NATIVE_INT8);
+        hsize_t   dimsf[RANK1] = {NX};
+        DataSpace dataspace(RANK1, dimsf);
+        DataSet   dataset = file.createDataSet(DATASET_NAME, datatype, dataspace);
+        dataset.write(DATA, datatype);
+        dataset.close();
+
+        /*
+         * Read characters with internal null bytes as a string.
+         * The read std::string should NOT be truncated at the first null byte.
+         */
+
+        dataset = file.openDataSet(DATASET_NAME);
+        dataset.read(str, datatype);
+        dataset.close();
+        verify_val(str.length(), NX, "test_read_string", __LINE__, __FILE__);
+        verify_val(str, EXPECTED_STR, "test_read_string", __LINE__, __FILE__);
+
+        /*
+         * Write the H5std_string back to the dataset.
+         */
+        dataset = file.openDataSet(DATASET_NAME);
+        dataset.write(str, datatype);
+        dataset.close();
+
+        /*
+         * Read characters with internal null bytes as a string, after rewrite.
+         * The read std::string should NOT be truncated at the first null byte.
+         */
+
+        dataset = file.openDataSet(DATASET_NAME);
+        dataset.read(str, datatype);
+        dataset.close();
+        verify_val(str.length(), NX, "test_read_string", __LINE__, __FILE__);
+        verify_val(str, EXPECTED_STR, "test_read_string", __LINE__, __FILE__);
+
+        /*
+         * Success
+         */
+        PASSED();
+        return 0;
+    }
+    catch (Exception &E) {
+        // H5_FAILED should probably be invoked before verify_val
+        H5_FAILED();
+        issue_fail_msg("test_read_string", __LINE__, __FILE__);
+
+        // clean up and return with failure
+        return -1;
+    }
+} // test_read_string
+
 /*-------------------------------------------------------------------------
  * Function:    test_dset
  *
@@ -1406,6 +1480,7 @@ test_dset()
         nerrors += test_virtual() < 0 ? 1 : 0;
         nerrors += test_operator(file) < 0 ? 1 : 0;
         nerrors += test_chunk_cache(fapl) < 0 ? 1 : 0;
+        nerrors += test_read_string(file) < 0 ? 1 : 0;
 
         // Close group "emit diagnostics".
         grp.close();
@@ -1429,8 +1504,6 @@ test_dset()
  * Purpose      Cleanup temporary test files
  *
  * Return       None
- *
- * Programmer   (use C version)
  *-------------------------------------------------------------------------
  */
 extern "C" void
