@@ -60,7 +60,7 @@ Java_hdf_hdf5lib_H5_H5Pget_1userblock(JNIEnv *env, jclass clss, jlong plist, jlo
 {
     jboolean isCopy;
     hsize_t  s;
-    jlong *  theArray = NULL;
+    jlong   *theArray = NULL;
     herr_t   status   = FAIL;
 
     UNUSED(clss);
@@ -110,7 +110,7 @@ JNIEXPORT jint JNICALL
 Java_hdf_hdf5lib_H5_H5Pget_1sizes(JNIEnv *env, jclass clss, jlong plist, jlongArray size)
 {
     jboolean isCopy;
-    jlong *  theArray = NULL;
+    jlong   *theArray = NULL;
     jsize    arrLen;
     size_t   ss;
     size_t   sa;
@@ -172,7 +172,7 @@ Java_hdf_hdf5lib_H5_H5Pget_1sym_1k(JNIEnv *env, jclass clss, jlong plist, jintAr
 {
     jboolean isCopy;
     jsize    arrLen;
-    jint *   theArray = NULL;
+    jint    *theArray = NULL;
     herr_t   status   = FAIL;
 
     UNUSED(clss);
@@ -227,7 +227,7 @@ JNIEXPORT jint JNICALL
 Java_hdf_hdf5lib_H5_H5Pget_1istore_1k(JNIEnv *env, jclass clss, jlong plist, jintArray ik)
 {
     jboolean isCopy;
-    jint *   theArray = NULL;
+    jint    *theArray = NULL;
     herr_t   status   = FAIL;
 
     UNUSED(clss);
@@ -294,7 +294,7 @@ Java_hdf_hdf5lib_H5_H5Pset_1file_1space_1strategy(JNIEnv *env, jclass clss, jlon
 {
     UNUSED(clss);
 
-    if (H5Pset_file_space_strategy((hid_t)fcpl_id, (H5F_fspace_strategy_t)strategy, (hbool_t)persist,
+    if (H5Pset_file_space_strategy((hid_t)fcpl_id, (H5F_fspace_strategy_t)strategy, (bool)persist,
                                    (hsize_t)threshold) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
@@ -313,8 +313,8 @@ Java_hdf_hdf5lib_H5_H5Pget_1file_1space_1strategy(JNIEnv *env, jclass clss, jlon
 {
     H5F_fspace_strategy_t thestrategy = H5F_FSPACE_STRATEGY_FSM_AGGR; /* Library default */
     jboolean              isCopy;
-    jboolean *            persistArray   = NULL;
-    jlong *               thresholdArray = NULL;
+    jboolean             *persistArray   = NULL;
+    jlong                *thresholdArray = NULL;
     herr_t                status         = FAIL;
 
     UNUSED(clss);
@@ -325,7 +325,7 @@ Java_hdf_hdf5lib_H5_H5Pget_1file_1space_1strategy(JNIEnv *env, jclass clss, jlon
         PIN_LONG_ARRAY(ENVONLY, threshold, thresholdArray, &isCopy,
                        "H5Pget_file_space: threshold not pinned");
 
-    if ((status = H5Pget_file_space_strategy((hid_t)fcpl_id, &thestrategy, (hbool_t *)persistArray,
+    if ((status = H5Pget_file_space_strategy((hid_t)fcpl_id, &thestrategy, (bool *)persistArray,
                                              (hsize_t *)thresholdArray)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
@@ -346,8 +346,8 @@ done:
 JNIEXPORT jboolean JNICALL
 Java_hdf_hdf5lib_H5_H5Pget_1file_1space_1strategy_1persist(JNIEnv *env, jclass clss, jlong fcpl_id)
 {
-    hbool_t persist = FALSE;
-    herr_t  status  = FAIL;
+    bool   persist = false;
+    herr_t status  = FAIL;
 
     UNUSED(clss);
 
@@ -466,7 +466,7 @@ Java_hdf_hdf5lib_H5_H5Pget_1shared_1mesg_1index(JNIEnv *env, jclass clss, jlong
 {
     jboolean isCopy;
     unsigned nindexes; /* Number of SOHM indexes */
-    jint *   theArray = NULL;
+    jint    *theArray = NULL;
     herr_t   retVal   = FAIL;
 
     UNUSED(clss);
@@ -545,7 +545,7 @@ Java_hdf_hdf5lib_H5_H5Pget_1shared_1mesg_1phase_1change(JNIEnv *env, jclass clss
                                                         jintArray size)
 {
     jboolean isCopy;
-    jint *   theArray = NULL;
+    jint    *theArray = NULL;
     herr_t   retVal   = FAIL;
 
     UNUSED(clss);
