@@ -14,9 +14,9 @@
  * Purpose:	Implicit (Non Index) chunked I/O functions.
  *
  *          This is used when the dataset is:
- *			- extendible but with fixed max. dims
- *			- with early allocation
- *			- without filter
+ *            - extendible but with fixed max. dims
+ *            - with early allocation
+ *            - without filter
  *
  *          The chunk coordinate is mapped into the actual disk addresses
  *          for the chunk without indexing.
@@ -31,12 +31,12 @@
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"   /* Generic Functions			*/
-#include "H5Dpkg.h"      /* Datasets				*/
-#include "H5Eprivate.h"  /* Error handling		  	*/
+#include "H5private.h"   /* Generic Functions                    */
+#include "H5Dpkg.h"      /* Datasets                             */
+#include "H5Eprivate.h"  /* Error handling                       */
 #include "H5FLprivate.h" /* Free Lists                           */
-#include "H5MFprivate.h" /* File space management		*/
-#include "H5VMprivate.h" /* Vector functions			*/
+#include "H5MFprivate.h" /* File space management                */
+#include "H5VMprivate.h" /* Vector functions                     */
 
 /****************/
 /* Local Macros */
@@ -51,18 +51,22 @@
 /********************/
 
 /* Non Index chunking I/O ops */
-static herr_t  H5D__none_idx_create(const H5D_chk_idx_info_t *idx_info);
-static hbool_t H5D__none_idx_is_space_alloc(const H5O_storage_chunk_t *storage);
-static herr_t  H5D__none_idx_get_addr(const H5D_chk_idx_info_t *idx_info, H5D_chunk_ud_t *udata);
-static int     H5D__none_idx_iterate(const H5D_chk_idx_info_t *idx_info, H5D_chunk_cb_func_t chunk_cb,
-                                     void *chunk_udata);
-static herr_t  H5D__none_idx_remove(const H5D_chk_idx_info_t *idx_info, H5D_chunk_common_ud_t *udata);
-static herr_t  H5D__none_idx_delete(const H5D_chk_idx_info_t *idx_info);
-static herr_t  H5D__none_idx_copy_setup(const H5D_chk_idx_info_t *idx_info_src,
-                                        const H5D_chk_idx_info_t *idx_info_dst);
-static herr_t  H5D__none_idx_size(const H5D_chk_idx_info_t *idx_info, hsize_t *size);
-static herr_t  H5D__none_idx_reset(H5O_storage_chunk_t *storage, hbool_t reset_addr);
-static herr_t  H5D__none_idx_dump(const H5O_storage_chunk_t *storage, FILE *stream);
+static herr_t H5D__none_idx_create(const H5D_chk_idx_info_t *idx_info);
+static herr_t H5D__none_idx_open(const H5D_chk_idx_info_t *idx_info);
+static herr_t H5D__none_idx_close(const H5D_chk_idx_info_t *idx_info);
+static herr_t H5D__none_idx_is_open(const H5D_chk_idx_info_t *idx_info, bool *is_open);
+static bool   H5D__none_idx_is_space_alloc(const H5O_storage_chunk_t *storage);
+static herr_t H5D__none_idx_get_addr(const H5D_chk_idx_info_t *idx_info, H5D_chunk_ud_t *udata);
+static herr_t H5D__none_idx_load_metadata(const H5D_chk_idx_info_t *idx_info);
+static int    H5D__none_idx_iterate(const H5D_chk_idx_info_t *idx_info, H5D_chunk_cb_func_t chunk_cb,
+                                    void *chunk_udata);
+static herr_t H5D__none_idx_remove(const H5D_chk_idx_info_t *idx_info, H5D_chunk_common_ud_t *udata);
+static herr_t H5D__none_idx_delete(const H5D_chk_idx_info_t *idx_info);
+static herr_t H5D__none_idx_copy_setup(const H5D_chk_idx_info_t *idx_info_src,
+                                       const H5D_chk_idx_info_t *idx_info_dst);
+static herr_t H5D__none_idx_size(const H5D_chk_idx_info_t *idx_info, hsize_t *size);
+static herr_t H5D__none_idx_reset(H5O_storage_chunk_t *storage, bool reset_addr);
+static herr_t H5D__none_idx_dump(const H5O_storage_chunk_t *storage, FILE *stream);
 
 /*********************/
 /* Package Variables */
@@ -70,12 +74,16 @@ static herr_t  H5D__none_idx_dump(const H5O_storage_chunk_t *storage, FILE *stre
 
 /* Non Index chunk I/O ops */
 const H5D_chunk_ops_t H5D_COPS_NONE[1] = {{
-    FALSE,                        /* Non-indexed chunking don't current support SWMR access */
+    false,                        /* Non-indexed chunking don't current support SWMR access */
     NULL,                         /* init */
     H5D__none_idx_create,         /* create */
+    H5D__none_idx_open,           /* open */
+    H5D__none_idx_close,          /* close */
+    H5D__none_idx_is_open,        /* is_open */
     H5D__none_idx_is_space_alloc, /* is_space_alloc */
     NULL,                         /* insert */
     H5D__none_idx_get_addr,       /* get_addr */
+    H5D__none_idx_load_metadata,  /* load_metadata */
     NULL,                         /* resize */
     H5D__none_idx_iterate,        /* iterate */
     H5D__none_idx_remove,         /* remove */
@@ -97,12 +105,12 @@ const H5D_chunk_ops_t H5D_COPS_NONE[1] = {{
 /*******************/
 
 /*-------------------------------------------------------------------------
- * Function:	H5D__none_idx_create
+ * Function:    H5D__none_idx_create
  *
- * Purpose:	Allocate memory for the maximum # of chunks in the dataset.
+ * Purpose:     Allocate memory for the maximum # of chunks in the dataset.
  *
- * Return:	Non-negative on success
- *		Negative on failure.
+ * Return:      Non-negative on success
+ *              Negative on failure.
  *
  *-------------------------------------------------------------------------
  */
@@ -141,15 +149,77 @@ done:
 } /* end H5D__none_idx_create() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5D__none_idx_is_space_alloc
+ * Function:    H5D__none_idx_open
  *
- * Purpose:	Query if space for the dataset chunks is allocated
+ * Purpose:     Opens an existing "none" index. Currently a no-op.
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:      SUCCEED (can't fail)
  *
  *-------------------------------------------------------------------------
  */
-static hbool_t
+static herr_t
+H5D__none_idx_open(const H5D_chk_idx_info_t H5_ATTR_UNUSED *idx_info)
+{
+    FUNC_ENTER_PACKAGE_NOERR
+
+    /* NO OP */
+
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* end H5D__none_idx_open() */
+
+/*-------------------------------------------------------------------------
+ * Function:    H5D__none_idx_close
+ *
+ * Purpose:     Closes an existing "none" index. Currently a no-op.
+ *
+ * Return:      SUCCEED (can't fail)
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5D__none_idx_close(const H5D_chk_idx_info_t H5_ATTR_UNUSED *idx_info)
+{
+    FUNC_ENTER_PACKAGE_NOERR
+
+    /* NO OP */
+
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* end H5D__none_idx_close() */
+
+/*-------------------------------------------------------------------------
+ * Function:    H5D__none_idx_is_open
+ *
+ * Purpose:     Query if the index is opened or not
+ *
+ * Return:      SUCCEED (can't fail)
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5D__none_idx_is_open(const H5D_chk_idx_info_t H5_ATTR_NDEBUG_UNUSED *idx_info, bool *is_open)
+{
+    FUNC_ENTER_PACKAGE_NOERR
+
+    assert(idx_info);
+    assert(idx_info->storage);
+    assert(H5D_CHUNK_IDX_NONE == idx_info->storage->idx_type);
+    assert(is_open);
+
+    *is_open = true;
+
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* end H5D__none_idx_is_open() */
+
+/*-------------------------------------------------------------------------
+ * Function:    H5D__none_idx_is_space_alloc
+ *
+ * Purpose:     Query if space for the dataset chunks is allocated
+ *
+ * Return:      true/false
+ *
+ *-------------------------------------------------------------------------
+ */
+static bool
 H5D__none_idx_is_space_alloc(const H5O_storage_chunk_t *storage)
 {
     FUNC_ENTER_PACKAGE_NOERR
@@ -157,16 +227,16 @@ H5D__none_idx_is_space_alloc(const H5O_storage_chunk_t *storage)
     /* Check args */
     assert(storage);
 
-    FUNC_LEAVE_NOAPI((hbool_t)H5_addr_defined(storage->idx_addr))
+    FUNC_LEAVE_NOAPI((bool)H5_addr_defined(storage->idx_addr))
 } /* end H5D__none_idx_is_space_alloc() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5D__none_idx_get_addr
+ * Function:    H5D__none_idx_get_addr
  *
- * Purpose:	Get the file address of a chunk.
- *		Save the retrieved information in the udata supplied.
+ * Purpose:     Get the file address of a chunk.
+ *              Save the retrieved information in the udata supplied.
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:      Non-negative on success/Negative on failure
  *
  *-------------------------------------------------------------------------
  */
@@ -200,12 +270,32 @@ H5D__none_idx_get_addr(const H5D_chk_idx_info_t *idx_info, H5D_chunk_ud_t *udata
 } /* H5D__none_idx_get_addr() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5D__none_idx_iterate
+ * Function:    H5D__none_idx_load_metadata
  *
- * Purpose:	Iterate over the chunks in an index, making a callback
+ * Purpose:     Load additional chunk index metadata beyond the chunk index
+ *              itself. Currently a no-op.
+ *
+ * Return:      Non-negative on success/Negative on failure
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5D__none_idx_load_metadata(const H5D_chk_idx_info_t H5_ATTR_UNUSED *idx_info)
+{
+    FUNC_ENTER_PACKAGE_NOERR
+
+    /* NO OP */
+
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* H5D__none_idx_load_metadata() */
+
+/*-------------------------------------------------------------------------
+ * Function:    H5D__none_idx_iterate
+ *
+ * Purpose:     Iterate over the chunks in an index, making a callback
  *              for each one.
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:      Non-negative on success/Negative on failure
  *
  *-------------------------------------------------------------------------
  */
@@ -275,13 +365,13 @@ done:
 } /* end H5D__none_idx_iterate() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5D__none_idx_remove
+ * Function:    H5D__none_idx_remove
  *
- * Purpose:	Remove chunk from index.
+ * Purpose:     Remove chunk from index.
  *
- * Note:	Chunks can't be removed (or added) to datasets with this
- *		form of index - all the space for all the chunks is always
- *		allocated in the file.
+ * Note:        Chunks can't be removed (or added) to datasets with this
+ *              form of index - all the space for all the chunks is always
+ *              allocated in the file.
  *
  * Return:	Non-negative on success/Negative on failure
  *
@@ -299,12 +389,12 @@ H5D__none_idx_remove(const H5D_chk_idx_info_t H5_ATTR_UNUSED *idx_info,
 } /* H5D__none_idx_remove() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5D__none_idx_delete
+ * Function:    H5D__none_idx_delete
  *
- * Purpose:	Delete raw data storage for entire dataset (i.e. all chunks)
+ * Purpose:     Delete raw data storage for entire dataset (i.e. all chunks)
  *
- * Return:	Success:	Non-negative
- *		Failure:	negative
+ * Return:      Success:    Non-negative
+ *              Failure:    negative
  *
  *-------------------------------------------------------------------------
  */
@@ -337,11 +427,11 @@ done:
 } /* end H5D__none_idx_delete() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5D__none_idx_copy_setup
+ * Function:    H5D__none_idx_copy_setup
  *
- * Purpose:	Set up any necessary information for copying chunks
+ * Purpose:     Set up any necessary information for copying chunks
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:      Non-negative on success/Negative on failure
  *
  *-------------------------------------------------------------------------
  */
@@ -407,16 +497,16 @@ H5D__none_idx_size(const H5D_chk_idx_info_t H5_ATTR_UNUSED *idx_info, hsize_t *i
 } /* end H5D__none_idx_size() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5D__none_idx_reset
+ * Function:    H5D__none_idx_reset
  *
- * Purpose:	Reset indexing information.
+ * Purpose:     Reset indexing information.
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:      Non-negative on success/Negative on failure
  *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5D__none_idx_reset(H5O_storage_chunk_t *storage, hbool_t reset_addr)
+H5D__none_idx_reset(H5O_storage_chunk_t *storage, bool reset_addr)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
@@ -431,11 +521,11 @@ H5D__none_idx_reset(H5O_storage_chunk_t *storage, hbool_t reset_addr)
 } /* end H5D__none_idx_reset() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5D__none_idx_dump
+ * Function:    H5D__none_idx_dump
  *
- * Purpose:	Dump
+ * Purpose:     Dump
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:      Non-negative on success/Negative on failure
  *
  *-------------------------------------------------------------------------
  */
