@@ -51,7 +51,7 @@
 /* Size of the extensible array header on disk */
 #define H5EA_HEADER_SIZE(sizeof_addr, sizeof_size)                                                           \
     (/* General metadata fields */                                                                           \
-     H5EA_METADATA_PREFIX_SIZE(TRUE)                                                                         \
+     H5EA_METADATA_PREFIX_SIZE(true)                                                                         \
                                                                                                              \
      /* General array information */                                                                         \
      + 1 /* Element Size */                                                                                  \
@@ -83,7 +83,7 @@
 /* Size of the extensible array index block on disk */
 #define H5EA_IBLOCK_SIZE(i)                                                                                  \
     (/* General metadata fields */                                                                           \
-     H5EA_METADATA_PREFIX_SIZE(TRUE)                                                                         \
+     H5EA_METADATA_PREFIX_SIZE(true)                                                                         \
                                                                                                              \
      /* Sanity-checking fields */                                                                            \
      + (i)->hdr->sizeof_addr /* File address of array owning the block */                                    \
@@ -98,7 +98,7 @@
 /* Size of the extensible array super block on disk */
 #define H5EA_SBLOCK_SIZE(s)                                                                                  \
     (/* General metadata fields */                                                                           \
-     H5EA_METADATA_PREFIX_SIZE(TRUE)                                                                         \
+     H5EA_METADATA_PREFIX_SIZE(true)                                                                         \
                                                                                                              \
      /* Sanity-checking fields */                                                                            \
      + (s)->hdr->sizeof_addr  /* File address of array owning the block */                                   \
@@ -114,7 +114,7 @@
 /* Size of the extensible array data block prefix on disk */
 #define H5EA_DBLOCK_PREFIX_SIZE(d)                                                                           \
     (/* General metadata fields */                                                                           \
-     H5EA_METADATA_PREFIX_SIZE(TRUE)                                                                         \
+     H5EA_METADATA_PREFIX_SIZE(true)                                                                         \
                                                                                                              \
      /* Sanity-checking fields */                                                                            \
      + (d)->hdr->sizeof_addr  /* File address of array owning the block */                                   \
@@ -185,7 +185,7 @@ typedef struct H5EA_hdr_t {
     size_t        size;           /* Size of header in file */
     H5F_t        *f;              /* Pointer to file for extensible array */
     size_t        file_rc;        /* Reference count of files using array header */
-    hbool_t       pending_delete; /* Array is pending deletion */
+    bool          pending_delete; /* Array is pending deletion */
     size_t        sizeof_addr;    /* Size of file addresses */
     size_t        sizeof_size;    /* Size of file sizes */
     unsigned char arr_off_size;   /* Size of array offsets (in bytes) */
@@ -201,7 +201,7 @@ typedef struct H5EA_hdr_t {
     void *cb_ctx; /* Callback context */
 
     /* SWMR / Flush dependency information (not stored) */
-    hbool_t             swmr_write; /* Flag indicating the file is opened with SWMR-write access */
+    bool                swmr_write; /* Flag indicating the file is opened with SWMR-write access */
     H5AC_proxy_entry_t *top_proxy;  /* 'Top' proxy cache entry for all array entries */
     void               *parent;     /* Pointer to 'top' proxy flush dependency
                                      * parent, if it exists, otherwise NULL.
@@ -263,7 +263,7 @@ typedef struct H5EA_sblock_t {
     size_t      size; /* Size of index block on disk                  */
 
     /* SWMR / Flush dependency information (not stored) */
-    hbool_t             has_hdr_depend; /* Whether this object has a flush dependency on the header */
+    bool                has_hdr_depend; /* Whether this object has a flush dependency on the header */
     H5AC_proxy_entry_t *top_proxy;      /* "Top" proxy cache entry for all array entries */
     H5EA_iblock_t      *parent;         /* Parent object for super block (index block)  */
 
@@ -291,7 +291,7 @@ typedef struct H5EA_dblock_t {
     size_t      size; /* Size of data block on disk                           */
 
     /* SWMR / Flush dependency information (not stored) */
-    hbool_t             has_hdr_depend; /* Whether this object has a flush dependency on the header */
+    bool                has_hdr_depend; /* Whether this object has a flush dependency on the header */
     H5AC_proxy_entry_t *top_proxy;      /* 'Top' proxy cache entry for all array entries */
     void               *parent;         /* Parent object for data block (index or super block)  */
 
@@ -314,7 +314,7 @@ typedef struct H5EA_dbk_page_t {
     size_t      size; /* Size of data block page on disk                  */
 
     /* SWMR / Flush dependency information (not stored) */
-    hbool_t             has_hdr_depend; /* Whether this object has a flush dependency on the header */
+    bool                has_hdr_depend; /* Whether this object has a flush dependency on the header */
     H5AC_proxy_entry_t *top_proxy;      /* "Top" proxy cache entry for all array entries */
     H5EA_sblock_t      *parent;         /* Parent object for data block page (super block)  */
 
@@ -403,7 +403,7 @@ H5_DLL herr_t      H5EA__hdr_dest(H5EA_hdr_t *hdr);
 
 /* Index block routines */
 H5_DLL H5EA_iblock_t *H5EA__iblock_alloc(H5EA_hdr_t *hdr);
-H5_DLL haddr_t        H5EA__iblock_create(H5EA_hdr_t *hdr, hbool_t *stats_changed);
+H5_DLL haddr_t        H5EA__iblock_create(H5EA_hdr_t *hdr, bool *stats_changed);
 H5_DLL H5EA_iblock_t *H5EA__iblock_protect(H5EA_hdr_t *hdr, unsigned flags);
 H5_DLL herr_t         H5EA__iblock_unprotect(H5EA_iblock_t *iblock, unsigned cache_flags);
 H5_DLL herr_t         H5EA__iblock_delete(H5EA_hdr_t *hdr);
@@ -411,7 +411,7 @@ H5_DLL herr_t         H5EA__iblock_dest(H5EA_iblock_t *iblock);
 
 /* Super block routines */
 H5_DLL H5EA_sblock_t *H5EA__sblock_alloc(H5EA_hdr_t *hdr, H5EA_iblock_t *parent, unsigned sblk_idx);
-H5_DLL haddr_t        H5EA__sblock_create(H5EA_hdr_t *hdr, H5EA_iblock_t *parent, hbool_t *stats_changed,
+H5_DLL haddr_t        H5EA__sblock_create(H5EA_hdr_t *hdr, H5EA_iblock_t *parent, bool *stats_changed,
                                           unsigned sblk_idx);
 H5_DLL H5EA_sblock_t *H5EA__sblock_protect(H5EA_hdr_t *hdr, H5EA_iblock_t *parent, haddr_t sblk_addr,
                                            unsigned sblk_idx, unsigned flags);
@@ -422,7 +422,7 @@ H5_DLL herr_t         H5EA__sblock_dest(H5EA_sblock_t *sblock);
 
 /* Data block routines */
 H5_DLL H5EA_dblock_t *H5EA__dblock_alloc(H5EA_hdr_t *hdr, void *parent, size_t nelmts);
-H5_DLL haddr_t  H5EA__dblock_create(H5EA_hdr_t *hdr, void *parent, hbool_t *stats_changed, hsize_t dblk_off,
+H5_DLL haddr_t  H5EA__dblock_create(H5EA_hdr_t *hdr, void *parent, bool *stats_changed, hsize_t dblk_off,
                                     size_t nelmts);
 H5_DLL unsigned H5EA__dblock_sblk_idx(const H5EA_hdr_t *hdr, hsize_t idx);
 H5_DLL H5EA_dblock_t *H5EA__dblock_protect(H5EA_hdr_t *hdr, void *parent, haddr_t dblk_addr,
