@@ -559,7 +559,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_write(H5HF_t *fh, void *_id, hbool_t H5_ATTR_UNUSED *id_changed, const void *obj)
+H5HF_write(H5HF_t *fh, void *_id, bool H5_ATTR_UNUSED *id_changed, const void *obj)
 {
     uint8_t *id = (uint8_t *)_id; /* Object ID */
     uint8_t  id_flags;            /* Heap ID flag bits */
@@ -747,7 +747,7 @@ done:
 herr_t
 H5HF_close(H5HF_t *fh)
 {
-    hbool_t pending_delete = FALSE;       /* Whether the heap is pending deletion */
+    bool    pending_delete = false;       /* Whether the heap is pending deletion */
     haddr_t heap_addr      = HADDR_UNDEF; /* Address of heap (for deletion) */
     herr_t  ret_value      = SUCCEED;     /* Return value */
 
@@ -795,7 +795,7 @@ H5HF_close(H5HF_t *fh)
             /* Set local info, so heap deletion can occur after decrementing the
              *  header's ref count
              */
-            pending_delete = TRUE;
+            pending_delete = true;
             heap_addr      = fh->hdr->heap_addr;
         } /* end if */
     }     /* end if */
@@ -856,7 +856,7 @@ H5HF_delete(H5F_t *f, haddr_t fh_addr)
 
     /* Check for files using shared heap header */
     if (hdr->file_rc)
-        hdr->pending_delete = TRUE;
+        hdr->pending_delete = true;
     else {
         /* Delete heap now, starting with header (unprotects header) */
         if (H5HF__hdr_delete(hdr) < 0)
