@@ -218,7 +218,7 @@ H5HF__dtable_debug(const H5HF_dtable_t *dtable, FILE *stream, int indent, int fw
  *-------------------------------------------------------------------------
  */
 void
-H5HF_hdr_print(const H5HF_hdr_t *hdr, hbool_t dump_internal, FILE *stream, int indent, int fwidth)
+H5HF_hdr_print(const H5HF_hdr_t *hdr, bool dump_internal, FILE *stream, int indent, int fwidth)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
@@ -333,7 +333,7 @@ H5HF_hdr_debug(H5F_t *f, haddr_t addr, FILE *stream, int indent, int fwidth)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap header");
 
     /* Print the information about the heap's header */
-    H5HF_hdr_print(hdr, FALSE, stream, indent, fwidth);
+    H5HF_hdr_print(hdr, false, stream, indent, fwidth);
 
 done:
     if (hdr && H5AC_unprotect(f, H5AC_FHEAP_HDR, addr, hdr, H5AC__NO_FLAGS_SET) < 0)
@@ -398,7 +398,7 @@ H5HF_dblock_debug_cb(H5FS_section_info_t *_sect, void *_udata)
         /* Calculate the length */
         len = end - start;
 
-        HDsnprintf(temp_str, sizeof(temp_str), "Section #%u:", (unsigned)udata->sect_count);
+        snprintf(temp_str, sizeof(temp_str), "Section #%u:", (unsigned)udata->sect_count);
         fprintf(udata->stream, "%*s%-*s %8zu, %8zu\n", udata->indent + 3, "", MAX(0, udata->fwidth - 9),
                 temp_str, start, len);
         udata->sect_count++;
@@ -482,7 +482,7 @@ H5HF_dblock_debug(H5F_t *f, haddr_t addr, FILE *stream, int indent, int fwidth,
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
 
     /* Initialize the free space information for the heap */
-    if (H5HF__space_start(hdr, FALSE) < 0)
+    if (H5HF__space_start(hdr, false) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize heap free space");
 
     /* If there is a free space manager for the heap, check for sections that overlap this block */
@@ -549,7 +549,7 @@ done:
  *-------------------------------------------------------------------------
  */
 void
-H5HF_iblock_print(const H5HF_indirect_t *iblock, hbool_t dump_internal, FILE *stream, int indent, int fwidth)
+H5HF_iblock_print(const H5HF_indirect_t *iblock, bool dump_internal, FILE *stream, int indent, int fwidth)
 {
     const H5HF_hdr_t *hdr;          /* Pointer to heap's header */
     char              temp_str[64]; /* Temporary string, for formatting */
@@ -591,13 +591,13 @@ H5HF_iblock_print(const H5HF_indirect_t *iblock, hbool_t dump_internal, FILE *st
     else
         fprintf(stream, "%*sDirect Block Entries: (address)\n", indent, "");
     for (u = 0; u < hdr->man_dtable.max_direct_rows && u < iblock->nrows; u++) {
-        HDsnprintf(temp_str, sizeof(temp_str), "Row #%u: (block size: %lu)", (unsigned)u,
-                   (unsigned long)hdr->man_dtable.row_block_size[u]);
+        snprintf(temp_str, sizeof(temp_str), "Row #%u: (block size: %lu)", (unsigned)u,
+                 (unsigned long)hdr->man_dtable.row_block_size[u]);
         fprintf(stream, "%*s%-*s\n", indent + 3, "", MAX(0, fwidth - 3), temp_str);
         for (v = 0; v < hdr->man_dtable.cparam.width; v++) {
             size_t off = (u * hdr->man_dtable.cparam.width) + v;
 
-            HDsnprintf(temp_str, sizeof(temp_str), "Col #%u:", (unsigned)v);
+            snprintf(temp_str, sizeof(temp_str), "Col #%u:", (unsigned)v);
             if (hdr->filter_len > 0)
                 fprintf(stream, "%*s%-*s %9" PRIuHADDR "/%6zu/%x\n", indent + 6, "", MAX(0, fwidth - 6),
                         temp_str, iblock->ents[off].addr, iblock->filt_ents[off].size,
@@ -616,13 +616,12 @@ H5HF_iblock_print(const H5HF_indirect_t *iblock, hbool_t dump_internal, FILE *st
                          H5VM_log2_of2(hdr->man_dtable.cparam.width);
         for (u = hdr->man_dtable.max_direct_rows; u < iblock->nrows; u++) {
             num_indirect_rows = (H5VM_log2_gen(hdr->man_dtable.row_block_size[u]) - first_row_bits) + 1;
-            HDsnprintf(temp_str, sizeof(temp_str), "Row #%u: (# of rows: %u)", (unsigned)u,
-                       num_indirect_rows);
+            snprintf(temp_str, sizeof(temp_str), "Row #%u: (# of rows: %u)", (unsigned)u, num_indirect_rows);
             fprintf(stream, "%*s%-*s\n", indent + 3, "", MAX(0, fwidth - 3), temp_str);
             for (v = 0; v < hdr->man_dtable.cparam.width; v++) {
                 size_t off = (u * hdr->man_dtable.cparam.width) + v;
 
-                HDsnprintf(temp_str, sizeof(temp_str), "Col #%u:", (unsigned)v);
+                snprintf(temp_str, sizeof(temp_str), "Col #%u:", (unsigned)v);
                 fprintf(stream, "%*s%-*s %9" PRIuHADDR "\n", indent + 6, "", MAX(0, fwidth - 6), temp_str,
                         iblock->ents[off].addr);
             } /* end for */
@@ -642,7 +641,7 @@ H5HF_iblock_print(const H5HF_indirect_t *iblock, hbool_t dump_internal, FILE *st
         fprintf(stream, "%*s%-*s %p\n", indent + 3, "", MAX(0, fwidth - 3),
                 "Parent indirect block address:", (void *)iblock->parent);
         if (iblock->parent)
-            H5HF_iblock_print(iblock->parent, TRUE, stream, indent + 6, fwidth);
+            H5HF_iblock_print(iblock->parent, true, stream, indent + 6, fwidth);
     } /* end if */
 
     FUNC_LEAVE_NOAPI_VOID
@@ -663,7 +662,7 @@ H5HF_iblock_debug(H5F_t *f, haddr_t addr, FILE *stream, int indent, int fwidth,
 {
     H5HF_hdr_t      *hdr         = NULL;    /* Fractal heap header info */
     H5HF_indirect_t *iblock      = NULL;    /* Fractal heap direct block info */
-    hbool_t          did_protect = FALSE;   /* Whether we protected the indirect block or not */
+    bool             did_protect = false;   /* Whether we protected the indirect block or not */
     herr_t           ret_value   = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
@@ -686,12 +685,12 @@ H5HF_iblock_debug(H5F_t *f, haddr_t addr, FILE *stream, int indent, int fwidth,
     /*
      * Load the heap indirect block
      */
-    if (NULL == (iblock = H5HF__man_iblock_protect(hdr, addr, nrows, NULL, 0, FALSE, H5AC__READ_ONLY_FLAG,
+    if (NULL == (iblock = H5HF__man_iblock_protect(hdr, addr, nrows, NULL, 0, false, H5AC__READ_ONLY_FLAG,
                                                    &did_protect)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTLOAD, FAIL, "unable to load fractal heap indirect block");
 
     /* Print the information about the heap's indirect block */
-    H5HF_iblock_print(iblock, FALSE, stream, indent, fwidth);
+    H5HF_iblock_print(iblock, false, stream, indent, fwidth);
 
 done:
     if (iblock && H5HF__man_iblock_unprotect(iblock, H5AC__NO_FLAGS_SET, did_protect) < 0)
@@ -778,7 +777,7 @@ H5HF_sects_debug(H5F_t *f, haddr_t fh_addr, FILE *stream, int indent, int fwidth
         HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap header");
 
     /* Initialize the free space information for the heap */
-    if (H5HF__space_start(hdr, FALSE) < 0)
+    if (H5HF__space_start(hdr, false) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, FAIL, "can't initialize heap free space");
 
     /* If there is a free space manager for the heap, iterate over them */
