@@ -285,11 +285,11 @@ H5VM_hyper_stride(unsigned n, const hsize_t *size, const hsize_t *total_size, co
  *              assumes that both hyperslabs are relative to the same array,
  *              for if not, they could not possibly be equal.
  *
- * Return:      TRUE if the hyperslabs are equal (that is,
+ * Return:      true if the hyperslabs are equal (that is,
  *              both refer to exactly the same elements of an
  *              array)
  *
- *              FALSE otherwise
+ *              false otherwise
  *
  *              Never returns FAIL
  *
@@ -301,23 +301,23 @@ H5VM_hyper_eq(unsigned n, const hsize_t *offset1, const hsize_t *size1, const hs
 {
     hsize_t  nelmts1 = 1, nelmts2 = 1;
     unsigned i;
-    htri_t   ret_value = TRUE; /* Return value */
+    htri_t   ret_value = true; /* Return value */
 
     /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     if (n == 0)
-        HGOTO_DONE(TRUE);
+        HGOTO_DONE(true);
 
     for (i = 0; i < n; i++) {
         if ((offset1 ? offset1[i] : 0) != (offset2 ? offset2[i] : 0))
-            HGOTO_DONE(FALSE);
+            HGOTO_DONE(false);
         if ((size1 ? size1[i] : 0) != (size2 ? size2[i] : 0))
-            HGOTO_DONE(FALSE);
+            HGOTO_DONE(false);
         if (0 == (nelmts1 *= (size1 ? size1[i] : 0)))
-            HGOTO_DONE(FALSE);
+            HGOTO_DONE(false);
         if (0 == (nelmts2 *= (size2 ? size2[i] : 0)))
-            HGOTO_DONE(FALSE);
+            HGOTO_DONE(false);
     }
 
 done:
@@ -569,7 +569,7 @@ H5VM_stride_fill(unsigned n, hsize_t elmt_size, const hsize_t *size, const hsize
     hsize_t  nelmts;                /*number of elements to fill	*/
     hsize_t  i;                     /*counter			*/
     int      j;                     /*counter			*/
-    hbool_t  carry;                 /*subtraction carray value	*/
+    bool     carry;                 /*subtraction carray value	*/
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
@@ -583,11 +583,11 @@ H5VM_stride_fill(unsigned n, hsize_t elmt_size, const hsize_t *size, const hsize
         memset(dst, (int)fill_value, (size_t)elmt_size); /*lint !e671 The elmt_size will be OK */
 
         /* Decrement indices and advance pointer */
-        for (j = (int)(n - 1), carry = TRUE; j >= 0 && carry; --j) {
+        for (j = (int)(n - 1), carry = true; j >= 0 && carry; --j) {
             dst += stride[j];
 
             if (--idx[j])
-                carry = FALSE;
+                carry = false;
             else {
                 assert(size);
                 idx[j] = size[j];
@@ -624,7 +624,7 @@ H5VM_stride_copy(unsigned n, hsize_t elmt_size, const hsize_t *size, const hsize
     hsize_t        nelmts;                      /*num elements to copy	*/
     hsize_t        i;                           /*counter		*/
     int            j;                           /*counters		*/
-    hbool_t        carry;                       /*carray for subtraction*/
+    bool           carry;                       /*carray for subtraction*/
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
@@ -640,12 +640,12 @@ H5VM_stride_copy(unsigned n, hsize_t elmt_size, const hsize_t *size, const hsize
             H5MM_memcpy(dst, src, (size_t)elmt_size); /*lint !e671 The elmt_size will be OK */
 
             /* Decrement indices and advance pointers */
-            for (j = (int)(n - 1), carry = TRUE; j >= 0 && carry; --j) {
+            for (j = (int)(n - 1), carry = true; j >= 0 && carry; --j) {
                 src += src_stride[j];
                 dst += dst_stride[j];
 
                 if (--idx[j])
-                    carry = FALSE;
+                    carry = false;
                 else {
                     assert(size);
                     idx[j] = size[j];
@@ -687,7 +687,7 @@ H5VM_stride_copy_s(unsigned n, hsize_t elmt_size, const hsize_t *size, const hss
     hsize_t        nelmts;                      /*num elements to copy	*/
     hsize_t        i;                           /*counter		*/
     int            j;                           /*counters		*/
-    hbool_t        carry;                       /*carray for subtraction*/
+    bool           carry;                       /*carray for subtraction*/
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
@@ -703,12 +703,12 @@ H5VM_stride_copy_s(unsigned n, hsize_t elmt_size, const hsize_t *size, const hss
             H5MM_memcpy(dst, src, (size_t)elmt_size); /*lint !e671 The elmt_size will be OK */
 
             /* Decrement indices and advance pointers */
-            for (j = (int)(n - 1), carry = TRUE; j >= 0 && carry; --j) {
+            for (j = (int)(n - 1), carry = true; j >= 0 && carry; --j) {
                 src += src_stride[j];
                 dst += dst_stride[j];
 
                 if (--idx[j])
-                    carry = FALSE;
+                    carry = false;
                 else {
                     assert(size);
                     idx[j] = size[j];
