@@ -21,7 +21,7 @@
    one in collective mode,
    2) We will read two datasets with the same hyperslab selection settings,
       1.  independent read to read independent output,
-          independent read to read collecive   output,
+          independent read to read collective   output,
     Compare the result,
     If the result is the same, then collective write succeeds.
       2.  collective read to read independent output,
@@ -498,7 +498,7 @@ coll_write_test(int chunk_factor)
 
          For testing collective hyperslab selection write
          In this test, we are using independent read to check
-         the correctedness of collective write compared with
+         the correctness of collective write compared with
          independent write,
 
          In order to thoroughly test this feature, we choose
@@ -593,7 +593,7 @@ coll_write_test(int chunk_factor)
     mspaceid = H5Screate_simple(MSPACE_RANK, mdim, NULL);
 
     /*
-     * Select two hyperslabs in memory. Hyperslabs has the same
+     * Select two hyperslabs in memory. Hyperslabs have the same
      * size and shape as the selected hyperslabs for the file dataspace
      * Only the starting point is different.
      * The first selection
@@ -833,7 +833,7 @@ coll_read_test(void)
     mspaceid = H5Screate_simple(MSPACE_RANK, mdim, NULL);
 
     /*
-     * Select two hyperslabs in memory. Hyperslabs has the same
+     * Select two hyperslabs in memory. Hyperslabs have the same
      * size and shape as the selected hyperslabs for the file dataspace.
      * Only the starting point is different.
      * The first selection
@@ -967,7 +967,7 @@ coll_read_test(void)
 **      sel_rank fastest changing indices, with origin (in the
 **    higher indices) as indicated by the start array.
 **
-**    Note that this function, is hard coded to presume a
+**    Note that this function is hard-coded to presume a
 **    maximum dataspace rank of 5.
 **
 **    While this maximum is declared as a constant, increasing
@@ -993,7 +993,7 @@ lower_dim_size_comp_test__select_checker_board(const int mpi_rank, const hid_t t
 #if LOWER_DIM_SIZE_COMP_TEST__SELECT_CHECKER_BOARD__DEBUG
     const char *fcnName = "lower_dim_size_comp_test__select_checker_board():";
 #endif
-    hbool_t   first_selection = TRUE;
+    bool      first_selection = true;
     int       i, j, k, l, m;
     int       ds_offset;
     int       sel_offset;
@@ -1045,7 +1045,7 @@ lower_dim_size_comp_test__select_checker_board(const int mpi_rank, const hid_t t
      * Note that the following computation depends on the C99
      * requirement that integer division discard any fraction
      * (truncation towards zero) to function correctly. As we
-     * now require C99, this shouldn't be a problem, but noting
+     * now require C99, this shouldn't be a problem, but note
      * it may save us some pain if we are ever obliged to support
      * pre-C99 compilers again.
      */
@@ -1074,7 +1074,7 @@ lower_dim_size_comp_test__select_checker_board(const int mpi_rank, const hid_t t
 
     /* Now set up the stride and block arrays, and portions of the start
      * and count arrays that will not be altered during the selection of
-     * the checker board.
+     * the checkerboard.
      */
     i = 0;
     while (i < ds_offset) {
@@ -1215,7 +1215,7 @@ lower_dim_size_comp_test__select_checker_board(const int mpi_rank, const hid_t t
 
                             if (first_selection) {
 
-                                first_selection = FALSE;
+                                first_selection = false;
 
                                 ret = H5Sselect_hyperslab(tgt_sid, H5S_SELECT_SET, &(start[ds_offset]),
                                                           &(stride[ds_offset]), &(count[ds_offset]),
@@ -1291,16 +1291,16 @@ lower_dim_size_comp_test__select_checker_board(const int mpi_rank, const hid_t t
 **  lower_dim_size_comp_test__verify_data():
 **
 **    Examine the supplied buffer to see if it contains the
-**    expected data.  Return TRUE if it does, and FALSE
+**    expected data.  Return true if it does, and false
 **      otherwise.
 **
-**    The supplied buffer is presumed to this process's slice
+**    The supplied buffer is presumed to be this process's slice
 **    of the target data set.  Each such slice will be an
 **    n-cube of rank (rank -1) and the supplied edge_size with
 **    origin (mpi_rank, 0, ... , 0) in the target data set.
 **
 **    Further, the buffer is presumed to be the result of reading
-**    or writing a checker board selection of an m (1 <= m <
+**    or writing a checkerboard selection of an m (1 <= m <
 **      rank) dimensional slice through this processes slice
 **    of the target data set.  Also, this slice must be parallel
 **    to the fastest changing indices.
@@ -1311,7 +1311,7 @@ lower_dim_size_comp_test__select_checker_board(const int mpi_rank, const hid_t t
 **      with the natural numbers listed in order from the origin
 **    along the fastest changing axis.
 **
-**      Thus for a 20x10x10 dataset, the value stored in location
+**      Thus, for a 20x10x10 dataset, the value stored in location
 **    (x, y, z) (assuming that z is the fastest changing index
 **    and x the slowest) is assumed to be:
 **
@@ -1319,7 +1319,7 @@ lower_dim_size_comp_test__select_checker_board(const int mpi_rank, const hid_t t
 **
 **    Further, supposing that this is process 10, this process's
 **    slice of the dataset would be a 10 x 10 2-cube with origin
-**    (10, 0, 0) in the data set, and would be initialize (prior
+**    (10, 0, 0) in the data set, and would be initialized (prior
 **    to the checkerboard selection) as follows:
 **
 **        1000, 1001, 1002, ... 1008, 1009
@@ -1344,20 +1344,20 @@ lower_dim_size_comp_test__select_checker_board(const int mpi_rank, const hid_t t
 
 #define LOWER_DIM_SIZE_COMP_TEST__VERIFY_DATA__DEBUG 0
 
-static hbool_t
+static bool
 lower_dim_size_comp_test__verify_data(uint32_t *buf_ptr,
 #if LOWER_DIM_SIZE_COMP_TEST__VERIFY_DATA__DEBUG
                                       const int mpi_rank,
 #endif /* LOWER_DIM_SIZE_COMP_TEST__VERIFY_DATA__DEBUG */
                                       const int rank, const int edge_size, const int checker_edge_size,
-                                      uint32_t first_expected_val, hbool_t buf_starts_in_checker)
+                                      uint32_t first_expected_val, bool buf_starts_in_checker)
 {
 #if LOWER_DIM_SIZE_COMP_TEST__VERIFY_DATA__DEBUG
     const char *fcnName = "lower_dim_size_comp_test__verify_data():";
 #endif
-    hbool_t   good_data = TRUE;
-    hbool_t   in_checker;
-    hbool_t   start_in_checker[5];
+    bool      good_data = true;
+    bool      in_checker;
+    bool      start_in_checker[5];
     uint32_t  expected_value;
     uint32_t *val_ptr;
     int       i, j, k, l, m;     /* to track position in n-cube */
@@ -1450,17 +1450,17 @@ lower_dim_size_comp_test__verify_data(uint32_t *buf_ptr,
 
                             if (*val_ptr != expected_value) {
 
-                                good_data = FALSE;
+                                good_data = false;
                             }
 
-                            /* zero out buffer for re-use */
+                            /* zero out buffer for reuse */
                             *val_ptr = 0;
                         }
                         else if (*val_ptr != 0) {
 
-                            good_data = FALSE;
+                            good_data = false;
 
-                            /* zero out buffer for re-use */
+                            /* zero out buffer for reuse */
                             *val_ptr = 0;
                         }
 
@@ -1506,7 +1506,7 @@ lower_dim_size_comp_test__verify_data(uint32_t *buf_ptr,
 #define LDSCT_DS_RANK 5
 
 static void
-lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_collective_io,
+lower_dim_size_comp_test__run_test(const int chunk_edge_size, const bool use_collective_io,
                                    const hid_t dset_type)
 {
 #if LOWER_DIM_SIZE_COMP_TEST__RUN_TEST__DEBUG
@@ -1516,8 +1516,8 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
     hsize_t     max_dims[32];
 #endif /* LOWER_DIM_SIZE_COMP_TEST__RUN_TEST__DEBUG */
     const char *filename;
-    hbool_t     data_ok   = FALSE;
-    hbool_t     mis_match = FALSE;
+    bool        data_ok   = false;
+    bool        mis_match = false;
     int         i;
     int         start_index;
     int         stop_index;
@@ -1859,10 +1859,10 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
     }
 
     check = H5Sselect_valid(mem_small_ds_sid);
-    VRFY((check == TRUE), "H5Sselect_valid(mem_small_ds_sid) returns TRUE");
+    VRFY((check == true), "H5Sselect_valid(mem_small_ds_sid) returns true");
 
     check = H5Sselect_valid(file_small_ds_sid);
-    VRFY((check == TRUE), "H5Sselect_valid(file_small_ds_sid) returns TRUE");
+    VRFY((check == true), "H5Sselect_valid(file_small_ds_sid) returns true");
 
     /* write the initial value of the small data set to file */
 #if LOWER_DIM_SIZE_COMP_TEST__RUN_TEST__DEBUG
@@ -1893,7 +1893,7 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
      * and reset the buffer to zero in passing.
      */
     expected_value = 0;
-    mis_match      = FALSE;
+    mis_match      = false;
     ptr_1          = small_ds_buf_1;
 
     i = 0;
@@ -1901,7 +1901,7 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
 
         if (*ptr_1 != expected_value) {
 
-            mis_match = TRUE;
+            mis_match = true;
         }
 
         *ptr_1 = (uint32_t)0;
@@ -1909,7 +1909,7 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
         ptr_1++;
         expected_value++;
     }
-    VRFY((mis_match == FALSE), "small ds init data good.");
+    VRFY((mis_match == false), "small ds init data good.");
 
     /* setup selections for writing initial data to the large data set */
     start[0] = (hsize_t)(mpi_rank + 1);
@@ -2017,10 +2017,10 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
 #endif /* LOWER_DIM_SIZE_COMP_TEST__RUN_TEST__DEBUG */
 
     check = H5Sselect_valid(mem_large_ds_sid);
-    VRFY((check == TRUE), "H5Sselect_valid(mem_large_ds_sid) returns TRUE");
+    VRFY((check == true), "H5Sselect_valid(mem_large_ds_sid) returns true");
 
     check = H5Sselect_valid(file_large_ds_sid);
-    VRFY((check == TRUE), "H5Sselect_valid(file_large_ds_sid) returns TRUE");
+    VRFY((check == true), "H5Sselect_valid(file_large_ds_sid) returns true");
 
     /* write the initial value of the large data set to file */
 #if LOWER_DIM_SIZE_COMP_TEST__RUN_TEST__DEBUG
@@ -2054,7 +2054,7 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
      * in passing, reset the buffer to zeros
      */
     expected_value = 0;
-    mis_match      = FALSE;
+    mis_match      = false;
     ptr_1          = large_ds_buf_1;
 
     i = 0;
@@ -2062,7 +2062,7 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
 
         if (*ptr_1 != expected_value) {
 
-            mis_match = TRUE;
+            mis_match = true;
         }
 
         *ptr_1 = (uint32_t)0;
@@ -2070,7 +2070,7 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
         ptr_1++;
         expected_value++;
     }
-    VRFY((mis_match == FALSE), "large ds init data good.");
+    VRFY((mis_match == false), "large ds init data good.");
 
     /***********************************/
     /***** INITIALIZATION COMPLETE *****/
@@ -2108,7 +2108,7 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
      * selections as having the same shape.
      */
     check = H5Sselect_shape_same(mem_large_ds_sid, file_small_ds_sid);
-    VRFY((check == TRUE), "H5Sselect_shape_same passed (1)");
+    VRFY((check == true), "H5Sselect_shape_same passed (1)");
 
     ret = H5Dread(small_dataset, H5T_NATIVE_UINT32, mem_large_ds_sid, file_small_ds_sid, xfer_plist,
                   large_ds_buf_1);
@@ -2123,7 +2123,7 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
 
     /* verify that expected data is retrieved */
 
-    data_ok = TRUE;
+    data_ok = true;
 
     start_index = (int)((large_sel_start[0] * large_dims[1] * large_dims[2] * large_dims[3] * large_dims[4]) +
                         (large_sel_start[1] * large_dims[2] * large_dims[3] * large_dims[4]) +
@@ -2142,14 +2142,14 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
 
         if (*ptr_1 != (uint32_t)0) {
 
-            data_ok = FALSE;
+            data_ok = false;
             *ptr_1  = (uint32_t)0;
         }
 
         ptr_1++;
     }
 
-    VRFY((data_ok == TRUE), "slice read from small ds data good(1).");
+    VRFY((data_ok == true), "slice read from small ds data good(1).");
 
     data_ok = lower_dim_size_comp_test__verify_data(ptr_1,
 #if LOWER_DIM_SIZE_COMP_TEST__VERIFY_DATA__DEBUG
@@ -2158,11 +2158,11 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
                                                     /* rank */ 2,
                                                     /* edge_size */ 10,
                                                     /*  checker_edge_size */ 3, expected_value,
-                                                    /* buf_starts_in_checker */ TRUE);
+                                                    /* buf_starts_in_checker */ true);
 
-    VRFY((data_ok == TRUE), "slice read from small ds data good(2).");
+    VRFY((data_ok == true), "slice read from small ds data good(2).");
 
-    data_ok = TRUE;
+    data_ok = true;
 
     ptr_1 += small_ds_slice_size;
 
@@ -2170,14 +2170,14 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
 
         if (*ptr_1 != (uint32_t)0) {
 
-            data_ok = FALSE;
+            data_ok = false;
             *ptr_1  = (uint32_t)0;
         }
 
         ptr_1++;
     }
 
-    VRFY((data_ok == TRUE), "slice read from small ds data good(3).");
+    VRFY((data_ok == true), "slice read from small ds data good(3).");
 
     /* read a checkerboard selection of a slice of the process slice of
      * the large on disk data set into the process slice of the small
@@ -2205,7 +2205,7 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
      * selections as having the same shape.
      */
     check = H5Sselect_shape_same(mem_small_ds_sid, file_large_ds_sid);
-    VRFY((check == TRUE), "H5Sselect_shape_same passed (2)");
+    VRFY((check == true), "H5Sselect_shape_same passed (2)");
 
     ret = H5Dread(large_dataset, H5T_NATIVE_UINT32, mem_small_ds_sid, file_large_ds_sid, xfer_plist,
                   small_ds_buf_1);
@@ -2220,7 +2220,7 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
 
     /* verify that expected data is retrieved */
 
-    data_ok = TRUE;
+    data_ok = true;
 
     expected_value =
         (uint32_t)((large_sel_start[0] * large_dims[1] * large_dims[2] * large_dims[3] * large_dims[4]) +
@@ -2242,14 +2242,14 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
 
         if (*ptr_1 != (uint32_t)0) {
 
-            data_ok = FALSE;
+            data_ok = false;
             *ptr_1  = (uint32_t)0;
         }
 
         ptr_1++;
     }
 
-    VRFY((data_ok == TRUE), "slice read from large ds data good(1).");
+    VRFY((data_ok == true), "slice read from large ds data good(1).");
 
     data_ok = lower_dim_size_comp_test__verify_data(ptr_1,
 #if LOWER_DIM_SIZE_COMP_TEST__VERIFY_DATA__DEBUG
@@ -2258,11 +2258,11 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
                                                     /* rank */ 2,
                                                     /* edge_size */ 10,
                                                     /*  checker_edge_size */ 3, expected_value,
-                                                    /* buf_starts_in_checker */ TRUE);
+                                                    /* buf_starts_in_checker */ true);
 
-    VRFY((data_ok == TRUE), "slice read from large ds data good(2).");
+    VRFY((data_ok == true), "slice read from large ds data good(2).");
 
-    data_ok = TRUE;
+    data_ok = true;
 
     ptr_1 += small_ds_slice_size;
 
@@ -2277,14 +2277,14 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
             }
 #endif /* LOWER_DIM_SIZE_COMP_TEST__VERIFY_DATA__DEBUG */
 
-            data_ok = FALSE;
+            data_ok = false;
             *ptr_1  = (uint32_t)0;
         }
 
         ptr_1++;
     }
 
-    VRFY((data_ok == TRUE), "slice read from large ds data good(3).");
+    VRFY((data_ok == true), "slice read from large ds data good(3).");
 
     /* Close dataspaces */
     ret = H5Sclose(full_mem_small_ds_sid);
@@ -2373,10 +2373,10 @@ lower_dim_size_comp_test(void)
     HDcompile_assert(sizeof(uint32_t) == sizeof(unsigned));
     for (use_collective_io = 0; use_collective_io <= 1; use_collective_io++) {
         chunk_edge_size = 0;
-        lower_dim_size_comp_test__run_test(chunk_edge_size, (hbool_t)use_collective_io, H5T_NATIVE_UINT);
+        lower_dim_size_comp_test__run_test(chunk_edge_size, (bool)use_collective_io, H5T_NATIVE_UINT);
 
         chunk_edge_size = 5;
-        lower_dim_size_comp_test__run_test(chunk_edge_size, (hbool_t)use_collective_io, H5T_NATIVE_UINT);
+        lower_dim_size_comp_test__run_test(chunk_edge_size, (bool)use_collective_io, H5T_NATIVE_UINT);
     } /* end for */
 
     return;
@@ -2398,11 +2398,11 @@ lower_dim_size_comp_test(void)
  *
  *        1) Reads or writes exactly one chunk,
  *
- *        2) Has no in memory buffer for any other chunk.
+ *        2) Has no in-memory buffer for any other chunk.
  *
- *        The test differers from Rob Latham's bug report in
- *        that is runs with an arbitrary number of proceeses,
- *        and uses a 1 dimensional dataset.
+ *        The test differs from Rob Latham's bug report in
+ *        that it runs with an arbitrary number of processes,
+ *        and uses a 1-dimensional dataset.
  *
  * Return:    void
  *-------------------------------------------------------------------------
@@ -2415,7 +2415,7 @@ link_chunk_collective_io_test(void)
 {
     /* const char *fcnName = "link_chunk_collective_io_test()"; */
     const char *filename;
-    hbool_t     mis_match = FALSE;
+    bool        mis_match = false;
     int         i;
     int         mrc;
     int         mpi_rank;
@@ -2552,7 +2552,7 @@ link_chunk_collective_io_test(void)
     VRFY((ret >= 0), "H5Pclose(xfer_plist) succeeded");
 
     /* verify the data */
-    mis_match = FALSE;
+    mis_match = false;
     for (i = 0; i < LINK_CHUNK_COLLECTIVE_IO_TEST_CHUNK_SIZE; i++) {
 
         diff = local_data_written[i] - local_data_read[i];
@@ -2560,10 +2560,10 @@ link_chunk_collective_io_test(void)
 
         if (diff >= 0.001) {
 
-            mis_match = TRUE;
+            mis_match = true;
         }
     }
-    VRFY((mis_match == FALSE), "dataset data good.");
+    VRFY((mis_match == false), "dataset data good.");
 
     /* Close dataspaces */
     ret = H5Sclose(write_mem_ds_sid);
